# Token

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token_hash** | **str** | Identity Token SHA256 Hash | 
**created_at** | **str** | Token creation time | 
**expires_at** | **str** | Token expiry time | 
**state** | **str** | Token state | 
**created_from** | **str** | Remote IP from where the token create request was received | 
**comment** | **str** | Comment provided at creation | [optional] 
**id_token** | **str** | Identity Token | [optional] 
**refresh_token** | **str** | Refresh Token | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

